pub fn render_human(map: &SourceMap, diagnostic: &Diagnostic) -> StringExpand description
Renders a diagnostic for a person, with the offending line and an underline.
pub fn render_human(map: &SourceMap, diagnostic: &Diagnostic) -> StringRenders a diagnostic for a person, with the offending line and an underline.